summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--perl-install/fs/mount_options.pm8
-rw-r--r--perl-install/install/NEWS2
2 files changed, 6 insertions, 4 deletions
diff --git a/perl-install/install/NEWS b/perl-install/install/NEWS
index f4152d2a7..dfd8c774b 100644
--- a/perl-install/install/NEWS
+++ b/perl-install/install/NEWS
@@ -1,8 +1,8 @@
- use better default title & icon for banners
- diskdrake:
o add support for 'relatime' mount option
- o default laptops to 'relatime' mount option rather than 'noatime'
o default all machines to 'relatime' mount option
+ (except laptops which use the stronger noatime)
o kill support for 'nodiratime' mount option
Version 10.4.168 - 13 August 2007, by Pascal "Pixel" Rigaux
diff --git a/perl-install/fs/mount_options.pm b/perl-install/fs/mount_options.pm
index 3e692cea5..21e042acd 100644
--- a/perl-install/fs/mount_options.pm
+++ b/perl-install/fs/mount_options.pm
@@ -198,12 +198,14 @@ sub set_default {
$options->{flush} = 1;
}
- #- relatime (wake up the hd less often / better performances)
+ if (isTrueFS($part)) {
+ #- noatime on laptops (do not wake up the hd)
+ #- otherwise relatime (wake up the hd less often / better performances)
#- Do not update inode access times on this
#- file system (e.g, for faster access on the
#- news spool to speed up news servers).
- $options->{relatime} = isTrueFS($part);
-
+ $options->{detect_devices::isLaptop() ? 'noatime': 'relatime'} = 1;
+ }
if ($part->{fs_type} eq 'nfs') {
put_in_hash($options, {
nosuid => 1, 'rsize=8192,wsize=8192' => 1, soft => 1,